Function radecdecimal,c1,c2,c3,c4,c5,c6

;+------------------------------------------------------
; 
; RADECDECIMAL
;
; Converts coordinates from HH:MM:SS, dd:mm:ss to
; decimal degrees.  Output is a 2-element vector [ra,dec].
;
; SYNTAX: [ra,dec] = radecdecimal(RAhr,RAmin,RAsec,Decdeg,Decmin,Decsec)
;
;   OR,   [ra,dec] = radecdecimal('HH:MM:SS','dd:mm:ss')
;
; Note: If the first syntax is used and Decdeg is a scalar, then 
;       the dec will be returned as positive if 0 < Dec < -1 degree.
;       
;
; HISTORY 
;      Written 8/28/2003 GDB
;      Modified to accept string coordinates 2/3/2005 GDB
;-------------------------------------------------------

if not(n_params() eq 2 or n_params() eq 6) then begin
    print,"CALLING SEQUENCE:"
    print,"    [ra,dec] = radecdecimal(rahr,ramin,rasec,ddeg,dmin,dsec)"
    print,"OR, [ra,dec] = radecdecimal('HH:MM:SS','dd:mm:ss')"
    print," "
    return,-1
endif

; Parse scalar values from inputs
if (n_params() eq 2) then begin
   rastring  = strtrim(c1,2)
   decstring = strtrim(c2,2)
   ; Get scalar RA values
   firstcolon  = strpos(rastring,':')
   rahr_len    = firstcolon - 0
   rahr        = double(strmid(rastring,0,rahr_len)) 
   secondcolon = strpos(rastring,':',firstcolon+1)
   ramin_len   = secondcolon - firstcolon - 1
   ramin       = double(strmid(rastring,firstcolon+1,ramin_len))
   tot_len     = strlen(rastring)
   rasec_len   = tot_len - secondcolon - 1
   rasec       = double(strmid(rastring,secondcolon+1,rasec_len))
   ; Get scalar Dec values
   firstcolon  = strpos(decstring,':')
   minussign   = strpos(decstring,'-')
   if (minussign eq 0) then begin
      sign = -1
      decdeg_start = 1
   endif else begin
      plussign = strpos(decstring,'+')
      if (plussign eq 0) then begin
         sign = 1
         decdeg_start = 1
      endif else begin
         sign = 1
         decdeg_start = 0
      endelse
   endelse
   decdeg_len  = firstcolon - decdeg_start
   decdeg      = sign*double(strmid(decstring,decdeg_start,decdeg_len))
   secondcolon = strpos(decstring,':',firstcolon+1)
   decmin_len  = secondcolon - firstcolon - 1
   decmin      = sign*double(strmid(decstring,firstcolon+1,decmin_len))
   tot_len     = strlen(decstring)
   decsec_len  = tot_len - secondcolon - 1
   decsec      = sign*double(strmid(decstring,secondcolon+1,decsec_len))
endif else begin
   rahr   = double(c1)
   ramin  = double(c2)
   rasec  = double(c3)
   decdeg = double(c4)
   sign   = abs(decdeg)/decdeg
   decmin = sign*double(c5)
   decsec = sign*double(c6)
   if (decdeg ge 0 and decdeg lt 1) then $
      print,'WARNING : Dec will be returned as positive if '+$
            '0 < Dec < -1 degree.'      
   if (c5 lt 0 or c6 lt 0) then begin
      print,'Dec minutes and seconds should be >= 0.'
      return,-1
   endif
endelse

; Convert RA to decimal
if (rahr lt 0 or ramin lt 0 or rasec lt 0) then begin
   print,'RA values should be >= 0.'
   retun,-1
endif
ra_tot_hrs = rahr + ramin/60d0 + rasec/3600d0
ra_decimal = ra_tot_hrs * 360d0/24d0

; Convert Dec to decimal
dec_decimal = decdeg + decmin/60d0 + decsec/3600d0

; Return result
return,[ra_decimal,dec_decimal]

end
